==> kubernetes-model-autoscaling-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/PodsMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
public class PodsMetricSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent<A>{
  public PodsMetricSourceFluentImpl() {
  }
  public PodsMetricSourceFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSource instance) {
    this.withMetricName(instance.getMetricName()); 
    this.withSelector(instance.getSelector()); 
    this.withTargetAverageValue(instance.getTargetAverageValue()); 
  }
  private java.lang.String metricName;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder selector;
  private io.fabric8.kubernetes.api.model.Quantity targetAverageValue;
  public java.lang.String getMetricName() {
    return this.metricName;
  }
  public A withMetricName(java.lang.String metricName) {
    this.metricName=metricName; return (A) this;
  }
  public java.lang.Boolean hasMetricName() {
    return this.metricName != null;
  }
  
  /**
   * Method is deprecated. use withMetricName instead.
   */
  @java.lang.Deprecated
  public A withNewMetricName(java.lang.String arg0) {
    return (A)withMetricName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> withNewSelector() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluentImpl.SelectorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluentImpl.SelectorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public io.fabric8.kubernetes.api.model.Quantity getTargetAverageValue() {
    return this.targetAverageValue;
  }
  public A withTargetAverageValue(io.fabric8.kubernetes.api.model.Quantity targetAverageValue) {
    this.targetAverageValue=targetAverageValue; return (A) this;
  }
  public java.lang.Boolean hasTargetAverageValue() {
    return this.targetAverageValue != null;
  }
  public A withNewTargetAverageValue(java.lang.String amount,java.lang.String format) {
    return (A)withTargetAverageValue(new Quantity(amount, format));
  }
  public A withNewTargetAverageValue(java.lang.String amount) {
    return (A)withTargetAverageValue(new Quantity(amount));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodsMetricSourceFluentImpl that = (PodsMetricSourceFluentImpl) o;
    if (metricName != null ? !metricName.equals(that.metricName) :that.metricName != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    if (targetAverageValue != null ? !targetAverageValue.equals(that.targetAverageValue) :that.targetAverageValue != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metricName,  selector,  targetAverageValue,  super.hashCode());
  }
  public class SelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) PodsMetricSourceFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-autoscaling-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/PodsMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.Quantity;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class PodsMetricSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent<A>{
  public PodsMetricSourceFluentImpl() {
  }
  public PodsMetricSourceFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSource instance) {
    this.withMetricName(instance.getMetricName()); 
    this.withSelector(instance.getSelector()); 
    this.withTargetAverageValue(instance.getTargetAverageValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String metricName;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder selector;
  private io.fabric8.kubernetes.api.model.Quantity targetAverageValue;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getMetricName() {
    return this.metricName;
  }
  public A withMetricName(java.lang.String metricName) {
    this.metricName=metricName; return (A) this;
  }
  public java.lang.Boolean hasMetricName() {
    return this.metricName != null;
  }
  
  /**
   * Method is deprecated. use withMetricName instead.
   */
  @java.lang.Deprecated
  public A withNewMetricName(java.lang.String arg0) {
    return (A)withMetricName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector() {
    return this.selector!=null?this.selector.build():null;
  }
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector) {
    _visitables.get("selector").remove(this.selector);
    if (selector!=null){ this.selector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(selector); _visitables.get("selector").add(this.selector);} return (A) this;
  }
  public java.lang.Boolean hasSelector() {
    return this.selector != null;
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> withNewSelector() {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluentImpl.SelectorNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluentImpl.SelectorNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editSelector() {
    return withNewSelectorLike(getSelector());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editOrNewSelector() {
    return withNewSelectorLike(getSelector() != null ? getSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewSelectorLike(getSelector() != null ? getSelector(): item);
  }
  public io.fabric8.kubernetes.api.model.Quantity getTargetAverageValue() {
    return this.targetAverageValue;
  }
  public A withTargetAverageValue(io.fabric8.kubernetes.api.model.Quantity targetAverageValue) {
    this.targetAverageValue=targetAverageValue; return (A) this;
  }
  public java.lang.Boolean hasTargetAverageValue() {
    return this.targetAverageValue != null;
  }
  public A withNewTargetAverageValue(java.lang.String amount,java.lang.String format) {
    return (A)withTargetAverageValue(new Quantity(amount, format));
  }
  public A withNewTargetAverageValue(java.lang.String amount) {
    return (A)withTargetAverageValue(new Quantity(amount));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodsMetricSourceFluentImpl that = (PodsMetricSourceFluentImpl) o;
    if (metricName != null ? !metricName.equals(that.metricName) :that.metricName != null) return false;
    if (selector != null ? !selector.equals(that.selector) :that.selector != null) return false;
    if (targetAverageValue != null ? !targetAverageValue.equals(that.targetAverageValue) :that.targetAverageValue != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metricName,  selector,  targetAverageValue,  additionalProperties,  super.hashCode());
  }
  public class SelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<N>> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta1.PodsMetricSourceFluent.SelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    SelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    SelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) PodsMetricSourceFluentImpl.this.withSelector(builder.build());
    }
    public N endSelector() {
      return and();
    }
    
  }
  
}
